@@ -4,7 +4,7 @@ use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -14,10 +14,10 @@ Chrome::DevToolsProtocol::Transport - choose the best transport backend
 
 our @loops = (
     ['Mojo/IOLoop.pm' => 'Chrome::DevToolsProtocol::Transport::Mojo' ],
+    ['IO/Async.pm'    => 'Chrome::DevToolsProtocol::Transport::NetAsync'],
     ['AnyEvent.pm'    => 'Chrome::DevToolsProtocol::Transport::AnyEvent'],
     ['AE.pm'          => 'Chrome::DevToolsProtocol::Transport::AnyEvent'],
-    # POE support would be nice
-    # IO::Async support would be nice, using Net::Async::HTTP
+    # native POE support would be nice
     
     # The fallback, will always catch due to loading strict (for now)
     ['strict.pm'      => 'Chrome::DevToolsProtocol::Transport::AnyEvent'],
@@ -68,6 +68,30 @@ sub best_implementation( $class, @candidates ) {
 
 1;
 
+=head1 SUPPORTED BACKENDS
+
+The module will try to guess the best backend to use. The currently supported
+backends are
+
+=over 4
+
+=item *
+
+L<IO::Async>
+
+=item *
+
+L<AnyEvent>
+
+=item *
+
+L<Mojolicious>
+
+=back
+
+If you want to substitute another backend, pass its class name instead
+of this module which only acts as a factory.
+
 =head1 REPOSITORY
 
 The public repository of this module is
